==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/CloudWatchLogs/InputLogEvent.pm <==
package Paws::CloudWatchLogs::InputLogEvent;
  use Moose;
  has Message => (is => 'ro', isa => 'Str', request_name => 'message', traits => ['NameInRequest'], required => 1);
  has Timestamp => (is => 'ro', isa => 'Int', request_name => 'timestamp', traits => ['NameInRequest'], required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchLogs::InputLogEvent

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::CloudWatchLogs::InputLogEvent object:

  $service_obj->Method(Att1 => { Message => $value, ..., Timestamp => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::CloudWatchLogs::InputLogEvent object:

  $result = $service_obj->Method(...);
  $result->Att1->Message

=head1 DESCRIPTION

Represents a log event, which is a record of activity that was recorded
by the application or resource being monitored.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Message => Str

  The raw event message.


=head2 B<REQUIRED> Timestamp => Int

  The time the event occurred, expressed as the number of milliseconds
fter Jan 1, 1970 00:00:00 UTC.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::CloudWatchLogs>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/CloudWatchLogs/InputLogEvent.pm <==
package Paws::CloudWatchLogs::InputLogEvent;
  use Moose;
  has Message => (is => 'ro', isa => 'Str', request_name => 'message', traits => ['NameInRequest'], required => 1);
  has Timestamp => (is => 'ro', isa => 'Int', request_name => 'timestamp', traits => ['NameInRequest'], required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchLogs::InputLogEvent

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::CloudWatchLogs::InputLogEvent object:

  $service_obj->Method(Att1 => { Message => $value, ..., Timestamp => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::CloudWatchLogs::InputLogEvent object:

  $result = $service_obj->Method(...);
  $result->Att1->Message

=head1 DESCRIPTION

Represents a log event, which is a record of activity that was recorded
by the application or resource being monitored.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Message => Str

  The raw event message.


=head2 B<REQUIRED> Timestamp => Int

  The time the event occurred, expressed as the number of milliseconds
after Jan 1, 1970 00:00:00 UTC.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::CloudWatchLogs>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
